@@ -82,9 +82,7 @@ CTHost::CTHost(const QString &cronBinary, CTInitializationError &ctInitializatio
 
 CTHost::~CTHost()
 {
-    foreach (CTCron *ctCron, mCrons) {
-        delete ctCron;
-    }
+    qDeleteAll(mCrons);
 }
 
 bool CTHost::allowDeny(char *name)
@@ -182,7 +180,7 @@ QString CTHost::createCTCron(const struct passwd *userInfos)
     }
 
     CTInitializationError ctInitializationError;
-    CTCron *p = new CTCron(mCrontabBinary, userInfos, currentUserCron, ctInitializationError);
+    auto p = new CTCron(mCrontabBinary, userInfos, currentUserCron, ctInitializationError);
     if (ctInitializationError.hasErrorMessage()) {
         delete p;
         return ctInitializationError.errorMessage();
